# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/forms/form/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/forms/form/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Forms\\Form\\": "packages/forms/form/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Forms\Form\Providers\FormServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Form'  => Forms\Form\Facades\Form::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Forms\\FormTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Forms\Form\Providers\FormServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Forms\Form\Providers\FormServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Forms\Form\Providers\FormServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/form/{modulename}

**User**

    http://path-to-route-folder/user/form/{modulename}

**Public**

    http://path-to-route-folder/forms


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/form/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/form/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/form/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/form/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/form/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/form/{modulename}/{slug}
    METHOD: GET